# NAME

rplot - Stream-based realtime scientific data plotter.

# SYNOPSIS

rplot [-vca] [-F #] [-x n[,n...]] [file...]

# DESCRIPTION

TBD

# OPTIONS

TBD

# INSTALLATION

```sh
$ pip3 install rplot
```

# AVAILABILITY

The latest version of **rplot** is available at PyPI
(https://pypi.org/project/rplot/) .

# AUTHOR

Hiroyuki Ohsaki <ohsaki[atmark]lsnl.jp>
